# MC/DC Documentation!

To build these docs locally run the following:
```bash 
conda install sphinx==7.2.6
pip install furo sphinx_toolbox
make html
```

Then launch ``build/html/index.html`` with your browser of choice